@@ -172,7 +172,6 @@ int fetch_request(t_session *session) {
 							memcpy(session->uploaded_file, session->config->upload_directory, session->config->upload_directory_len);
 							memcpy(session->uploaded_file + session->config->upload_directory_len, "/upload_XXXXXX", 15);
 
-							umask(S_IWGRP | S_IWOTH);
 							if ((upload_handle = mkstemp(session->uploaded_file)) == -1) {
 								free(session->uploaded_file);
 								session->uploaded_file = NULL;
@@ -212,7 +211,7 @@ int fetch_request(t_session *session) {
 							content_length = str_to_int(strstart);
 							*strend = '\r';
 							if ((content_length < 0) || (INT_MAX - content_length - 2 <= header_length)) {
-								result = 500;
+								result = 400;
 								break;
 							}
 
