@@ -217,10 +217,10 @@ static int add_string_to_buffer(char *str) {
  */
 int monitor_event(char *event, ...) {
 	char str[1024];
-	int size;
+	int size, i;
 	va_list args;
 
-	size = sprintf(str, "event\t");
+	size = i = sprintf(str, "event\t");
 
 	va_start(args, event);
 	size += vsnprintf(str + size, 1023 - size, event, args);
@@ -230,6 +230,16 @@ int monitor_event(char *event, ...) {
 		return -1;
 	}
 
+	while (i < size) {
+		if (str[i] == '\t') {
+			str[i] = ' ';
+		} else if (str[i] == '\n') {
+			str[i] = '#';
+		}
+
+		i++;
+	}
+
 	if ((size += snprintf(str + size, 1023 - size, "\t%ld\n", (long)time(NULL))) >= 1023) {
 		return -1;
 	}
